@@ -93,7 +93,7 @@ if pandas_import:
         qn_data[:] = quantile_normalize_np(qn_data.values, axis, target, ncpus)
         return qn_data
 
-    def quantile_normalize_file(
+    def incremental_quantile_normalize(
         infile: str,
         outfile: str,
         rowchunksize: int = 100_000,
@@ -146,8 +146,9 @@ if pandas_import:
         with TempFileHolder() as tfh:
             # loop over our column chunks and keep updating our target
             for i in range(math.ceil(nr_cols / colchunksize)):
-                col_start, col_end = i * colchunksize, np.clip(
-                    (i + 1) * colchunksize, 0, nr_cols
+                col_start, col_end = (
+                    i * colchunksize,
+                    np.clip((i + 1) * colchunksize, 0, nr_cols),
                 )
                 # read relevant columns
                 if dataformat == "hdf":
